@@ -114,25 +114,25 @@ class Monitor(object):
 		
 	def job_finished(self, job):
 		"""
-			Called when a job has completed.
+			(Virtual) Called when a job has completed.
 		"""
 		pass
 		
 	def job_started(self, job):
 		"""
-			Called just after a job is started.
+			(Virtual) Called just after a job is started.
 		"""
 		pass
 		
 	def job_output(self, job, line):
 		"""
-			Called for each line of output from a job.
+			(Virtual) Called for each line of output from a job.
 		"""
 		pass
 		
 	def gen_feedback(self):
 		"""
-			Called whenever the Monitor things feedback should be generated (in addition to the other
+			(Virtual) Called whenever the Monitor things feedback should be generated (in addition to the other
 			events). Generally this is called for each feedback_timeout period specified in the constructor.
 		"""
 		pass
@@ -162,6 +162,20 @@ class Job:
 		self.status = Job.STATUS_NONE
 		# Value of the exit code from the process, or None if not yet finished
 		self.exit_code = None
+		# An identifying name
+		self.name = None
+		
+	def get_ref_name(self):
+		"""
+			A reference name suitable for using in identifiers and files.
+		"""
+		if not self.name:
+			return self.id
+		
+		# generate simple safe filename
+		base = self.name.replace( '/', '_' ).replace( '\\', '_' ).replace( ' ', '_' )
+		keep = ('_','.')
+		return "".join( c for c in base if c.isalnum() or c in keep )
 
 		
 class FileMonitor(Monitor):
@@ -180,6 +194,12 @@ class FileMonitor(Monitor):
 		self.file_pattern = file_pattern
 		self.meta = meta
 		
+	def get_log_name(self,job):
+		"""
+			(Virtual) get the log of the log file to use.
+		"""
+		return self.file_pattern.format( job.get_ref_name() )
+		
 	def job_finished(self, job):
 		"""
 			Called when a job has completed.
@@ -193,7 +213,7 @@ class FileMonitor(Monitor):
 		"""
 			Called just after a job is started.
 		"""
-		job.log_name = self.file_pattern.format( job.id )
+		job.log_name = self.get_log_name(job)
 		job.log_file = open(job.log_name,'w')
 		job.got_output = False
 		
